// SPDX-License-Identifier: GPL-3.0-or-later
// Copyright 2023 Oliver Smith
#include "config.h"
#include "pages.h"
#include "ui.h"
#include <unl0kr/command_line.h>
#include <libintl.h>
#include <locale.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

static void show_usage(void)
{
	fprintf(stderr,
	"usage: ondev2 [-h|CONFIG]\n"
	"\n"
	"arguments:\n"
	"  -C, --config-override     Path to a config override file. Can be supplied\n"
        "                            multiple times. Config files are merged in the\n"
        "                            following order:\n"
        "                            * /etc/unl0kr.conf\n"
        "                            * /etc/unl0kr.conf.d/* (alphabetically)\n"
        "                            * Override files (in supplied order)\n"
        "  -g, --geometry=NxM[@X,Y]  Force a display size of N horizontal times M\n"
        "                            vertical pixels, offset horizontally by X\n"
        "                            pixels and vertically by Y pixels\n"
        "  -d  --dpi=N               Override the display's DPI value\n"
        "  -h, --help                Print this message and exit\n"
        "  -v, --verbose             Enable more detailed logging output on STDERR\n"
        "  -V, --version             Print the unl0kr version and exit\n");
}

static int parse_args(const char **path, int argc, const char **argv)
{
	*path = "/etc/ondev2.cfg";

	if (argc == 2) {
		if (strcmp(argv[1], "-h") == 0) {
			show_usage();
			return -1;
		}
		*path = argv[1];
	}
	return 0;
}

int main(int argc, char **argv)
{
	const char *path = "/etc/ondev2.cfg";
	ul_cli_opts opts = {0};

	/* Set OD2=1, so shell scripts know they were called from ondev2 */
	setenv("OD2", "1", 1);

	ul_cli_parse_opts(argc, argv, &opts);

	if (opts.num_config_files > 0) {
		path = opts.config_files[0];
	}
	if (od2_config_load(path) < 0)
		return 1;

	setlocale(LC_ALL, "");
	bindtextdomain("ondev2", "/usr/share/locale");
	textdomain("ondev2");

	od2_ui_init(OD2_PAGE_LANGUAGE, &opts);
	od2_ui_interact();
}
