#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "greatest.h"
#include "config.h"

int od2_load_load_config_file(const char *path);

/* wrapped by linker */
extern int __real_access(const char *__name, int __type);

int __wrap_access(const char *__name, int __type)
{
	/* We ALWAYS want to use the local defaults.cfg */
	if (strcmp(__name, OD2_DEFAULT_CONFIG) == 0)
		return -1;
	return __real_access(__name, __type);
}

TEST config_load_default(void)
{
	ASSERT_FALSE(od2_load_load_config_file("test/config/config_default.cfg"));
	/* Stuff we override */
	ASSERT_STR_EQ(g_config.device_arch, "");
	ASSERT_STR_EQ(g_config.device_name, "");
	ASSERT_STR_EQ(g_config.device_storage_emmc, "");
	ASSERT_STR_EQ(g_config.device_storage_sd, "");
	ASSERT_STR_EQ(g_config.device_boot_part_size, "256M");
	/* Stuff that shouldn't change after the second config is loaded */
	ASSERT_STR_EQ(g_config.device_boot_filesystem, "ext4");
	ASSERT_STR_EQ(g_config.device_boot_part_start, "2048");
	PASS();
}

TEST config_load_device(void)
{
	ASSERT_FALSE(od2_load_load_config_file("test/config/config_pinephone.cfg"));
	/* Stuff that should have changed */
	ASSERT_STR_EQ(g_config.device_arch, "aarch64");
	ASSERT_STR_EQ(g_config.device_name, "PINE64 PinePhone");
	ASSERT_STR_EQ(g_config.device_storage_emmc, "/dev/mmcblk2");
	ASSERT_STR_EQ(g_config.device_storage_sd, "/dev/mmcblk1");
	ASSERT_STR_EQ(g_config.device_boot_part_size, "128M");
	/* Stuff that shouldn't have changed*/
	ASSERT_STR_EQ(g_config.device_boot_filesystem, "ext4");
	ASSERT_STR_EQ(g_config.device_boot_part_start, "2048");
	PASS();
}

SUITE(config_load_and_override) {
	RUN_TEST(config_load_default);
	RUN_TEST(config_load_device);
}

GREATEST_MAIN_DEFS();

int main(int argc, char **argv)
{
	GREATEST_MAIN_BEGIN();

	RUN_SUITE(config_load_and_override);

	GREATEST_MAIN_END();
}
