#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "greatest.h"
#include "storages.h"
#include "config.h"

#define DEVICE_STORAGE_EMMC "/dev/sda9"

int od2_load_load_config_file(const char *path);

/* wrapped by linker */
extern int __real_access(const char *__name, int __type);

/* We use linker args to wrap the stdlib access() function so that
 * we can mock the storages.c code which checks to see if the block
 * device actually exists.
 */
int __wrap_access(const char *__name, int __type)
{
	if (strcmp(__name, DEVICE_STORAGE_EMMC) == 0)
		return 0;
	return __real_access(__name, __type);
}

TEST axolotl_storage_init(void)
{
	ASSERT_FALSE(od2_load_load_config_file("test/storages/defaults.cfg"));
	ASSERT_FALSE(od2_load_load_config_file("test/storages/axolotl.cfg"));
	// Checking the /boot mountpoint doesn't work because for some reason it
	// resolves to /dev/dm-0 or something.
	ASSERT_STR_EQ(g_config.mountpoint, "/");
	ASSERT_STR_EQ(DEVICE_STORAGE_EMMC, od2_storage_get_path(OD2_STORAGE_EMMC));
	ASSERT_FALSE(od2_storage_init());
	ASSERT_EQm("Only a single storage should be available", 1, od2_storage_count_available());
	ASSERT_ENUM_EQ(OD2_STORAGE_EMMC, od2_storage_get_boot_dev(), od2_storage_id_str);
	PASS();
}

TEST axolotl_storage_partitions(void)
{
	ASSERT_STR_EQ("/dev/mapper/sda9p1", od2_storage_get_boot_partition(OD2_STORAGE_EMMC));
	ASSERT_STR_EQ("/dev/mapper/sda9p2", od2_storage_get_root_partition(OD2_STORAGE_EMMC));
	ASSERT_STR_EQ("/dev/mapper/sda9p3", od2_storage_get_install_data_partition());
	PASS();
}

SUITE(shift_axolotl) {
	setenv("OD2_PROC_SELF_MOUNTS", "test/storages/proc_self_mounts_axolotl", 1);
	RUN_TEST(axolotl_storage_init);
	RUN_TEST(axolotl_storage_partitions);
}

GREATEST_MAIN_DEFS();

int main(int argc, char **argv)
{
	GREATEST_MAIN_BEGIN();

	RUN_SUITE(shift_axolotl);

	GREATEST_MAIN_END();
}
